﻿using CommunityToolkit.Mvvm.ComponentModel;
using CommunityToolkit.Mvvm.Input;
using RealisticHelloWorld.Domain.Interfaces;
using RealisticHelloWorld.Domain.Models;

namespace RealisticHelloWorld.ViewModels;


public partial class Counter : ObservableObject
{

    private readonly INumberMapper numberMapperService;
    private readonly NumberMap map;

    public Counter(INumberMapper mapperService)
    {
        numberMapperService = mapperService;
        map = numberMapperService.GetNumberMap();
    }

    [ObservableProperty]
    [NotifyPropertyChangedFor(nameof(CountText))]
    [NotifyCanExecuteChangedFor(nameof(IncreaseCounterCommand))]
    private int count;

    public string CountText
    {
        get
        {
            var text = "Click me";
            var word = map.ToWord(count);
            if (count is > 0 and < 11)
            {
                text = $"Clicked {word} " + (count == 1 ? "time" : "times");
            }
            SemanticScreenReader.Announce(text);
            return text;
        }
    }

    [RelayCommand(CanExecute = nameof(CanIncreaseCounter))]
    private void IncreaseCounter()
    {
        Count++;
    }

    private bool CanIncreaseCounter() => count is >= 0 and < 10;
}